#!/bin/bash

# Small example to demonstrate and test IDA on a 1000 x 1000 landscape.
# Note that you may not be able to run all of these, depending on your
# configuration of PETSc (whether HYPRE is installed), and available memory.

# YOU MUST SET THIS!
# It should contain the path to your ida executable (produced by compiling the
# IDA code)
exe=../bin/ida

echo ""
echo "4 processors, regular IDA, Richardson solver and ASM preconditioner, "
echo "calculating initial guess"
echo ""
mpirun -np 4 ${exe} -in dir.bin -out out.bin \
  -true true.bin -ksp_type richardson -pc_type asm -initguesscalc \
  -N 1000 -M 1000

echo ""
echo ""
echo "4 processors, hyrid IDA, Richardson solver and ASM preconditioner"
echo ""
mpirun -np 4 ${exe} -in dir.bin \
  -true true.bin -ksp_type richardson -pc_type asm -N 1000 -M 1000 \
  -onlycrossborder

echo ""
echo ""
echo "4 processors, hyrid IDA, Richardson solver and Euclid preconditioner, "
echo "Only solving the middle 500 x 500 landscape, and printing the PETSc "
echo "log summary"
echo ""
mpirun -np 4 ${exe} -in dir.bin \
  -ksp_type richardson -pc_type hypre -pc_hypre_type euclid \
  -fullN 1000 -fullM 1000 -firstcol 250 -firstrow 250 -N 500 -M 500 \
  -onlycrossborder -log_summary
